@@ -45,6 +45,13 @@ class TestUtils(base.TestCase):
         ret = _utils._filter_list(data, 'donald', {'other': 'duck'})
         self.assertEqual([el1], ret)
 
+    def test__filter_list_filter_jmespath(self):
+        el1 = dict(id=100, name='donald', other='duck')
+        el2 = dict(id=200, name='donald', other='trump')
+        data = [el1, el2]
+        ret = _utils._filter_list(data, 'donald', "[?other == `duck`]")
+        self.assertEqual([el1], ret)
+
     def test__filter_list_dict1(self):
         el1 = dict(id=100, name='donald', last='duck',
                    other=dict(category='duck'))
@@ -72,95 +79,6 @@ class TestUtils(base.TestCase):
                 }})
         self.assertEqual([el2, el3], ret)
 
-    def test_normalize_nova_secgroups(self):
-        nova_secgroup = dict(
-            id='abc123',
-            name='nova_secgroup',
-            description='A Nova security group',
-            rules=[
-                dict(id='123', from_port=80, to_port=81, ip_protocol='tcp',
-                     ip_range={'cidr': '0.0.0.0/0'}, parent_group_id='xyz123')
-            ]
-        )
-
-        expected = dict(
-            id='abc123',
-            name='nova_secgroup',
-            description='A Nova security group',
-            security_group_rules=[
-                dict(id='123', direction='ingress', ethertype='IPv4',
-                     port_range_min=80, port_range_max=81, protocol='tcp',
-                     remote_ip_prefix='0.0.0.0/0', security_group_id='xyz123')
-            ]
-        )
-
-        retval = _utils.normalize_nova_secgroups([nova_secgroup])[0]
-        self.assertEqual(expected, retval)
-
-    def test_normalize_nova_secgroups_negone_port(self):
-        nova_secgroup = dict(
-            id='abc123',
-            name='nova_secgroup',
-            description='A Nova security group with -1 ports',
-            rules=[
-                dict(id='123', from_port=-1, to_port=-1, ip_protocol='icmp',
-                     ip_range={'cidr': '0.0.0.0/0'}, parent_group_id='xyz123')
-            ]
-        )
-
-        retval = _utils.normalize_nova_secgroups([nova_secgroup])[0]
-        self.assertIsNone(retval['security_group_rules'][0]['port_range_min'])
-        self.assertIsNone(retval['security_group_rules'][0]['port_range_max'])
-
-    def test_normalize_nova_secgroup_rules(self):
-        nova_rules = [
-            dict(id='123', from_port=80, to_port=81, ip_protocol='tcp',
-                 ip_range={'cidr': '0.0.0.0/0'}, parent_group_id='xyz123')
-        ]
-        expected = [
-            dict(id='123', direction='ingress', ethertype='IPv4',
-                 port_range_min=80, port_range_max=81, protocol='tcp',
-                 remote_ip_prefix='0.0.0.0/0', security_group_id='xyz123')
-        ]
-        retval = _utils.normalize_nova_secgroup_rules(nova_rules)
-        self.assertEqual(expected, retval)
-
-    def test_normalize_volumes_v1(self):
-        vol = dict(
-            display_name='test',
-            display_description='description',
-            bootable=u'false',   # unicode type
-            multiattach='true',  # str type
-        )
-        expected = dict(
-            name=vol['display_name'],
-            display_name=vol['display_name'],
-            description=vol['display_description'],
-            display_description=vol['display_description'],
-            bootable=False,
-            multiattach=True,
-        )
-        retval = _utils.normalize_volumes([vol])
-        self.assertEqual([expected], retval)
-
-    def test_normalize_volumes_v2(self):
-        vol = dict(
-            display_name='test',
-            display_description='description',
-            bootable=False,
-            multiattach=True,
-        )
-        expected = dict(
-            name=vol['display_name'],
-            display_name=vol['display_name'],
-            description=vol['display_description'],
-            display_description=vol['display_description'],
-            bootable=False,
-            multiattach=True,
-        )
-        retval = _utils.normalize_volumes([vol])
-        self.assertEqual([expected], retval)
-
     def test_safe_dict_min_ints(self):
         """Test integer comparison"""
         data = [{'f1': 3}, {'f1': 2}, {'f1': 1}]
