@@ -115,14 +115,17 @@ class TestMemoryCache(base.TestCase):
         keystone_mock.projects.list.return_value = [project]
         self.cloud.cloud_config.config['identity_api_version'] = '3'
         self.assertEqual(
-            meta.obj_list_to_dict([project]), self.cloud.list_projects())
+            self.cloud._normalize_projects(meta.obj_list_to_dict([project])),
+            self.cloud.list_projects())
         project_b = fakes.FakeProject('project_b')
         keystone_mock.projects.list.return_value = [project, project_b]
         self.assertEqual(
-            meta.obj_list_to_dict([project]), self.cloud.list_projects())
+            self.cloud._normalize_projects(meta.obj_list_to_dict([project])),
+            self.cloud.list_projects())
         self.cloud.list_projects.invalidate(self.cloud)
         self.assertEqual(
-            meta.obj_list_to_dict([project, project_b]),
+            self.cloud._normalize_projects(
+                meta.obj_list_to_dict([project, project_b])),
             self.cloud.list_projects())
 
     @mock.patch('shade.OpenStackCloud.keystone_client')
@@ -131,14 +134,17 @@ class TestMemoryCache(base.TestCase):
         keystone_mock.tenants.list.return_value = [project]
         self.cloud.cloud_config.config['identity_api_version'] = '2'
         self.assertEqual(
-            meta.obj_list_to_dict([project]), self.cloud.list_projects())
+            self.cloud._normalize_projects(meta.obj_list_to_dict([project])),
+            self.cloud.list_projects())
         project_b = fakes.FakeProject('project_b')
         keystone_mock.tenants.list.return_value = [project, project_b]
         self.assertEqual(
-            meta.obj_list_to_dict([project]), self.cloud.list_projects())
+            self.cloud._normalize_projects(meta.obj_list_to_dict([project])),
+            self.cloud.list_projects())
         self.cloud.list_projects.invalidate(self.cloud)
         self.assertEqual(
-            meta.obj_list_to_dict([project, project_b]),
+            self.cloud._normalize_projects(
+                meta.obj_list_to_dict([project, project_b])),
             self.cloud.list_projects())
 
     @mock.patch('shade.OpenStackCloud.nova_client')
@@ -501,6 +507,36 @@ class TestMemoryCache(base.TestCase):
         fake_image_dict = self._image_dict(fake_image)
         self.assertEqual([fake_image_dict], self.cloud.list_images())
 
+    @mock.patch.object(occ.cloud_config.CloudConfig, 'get_api_version')
+    @mock.patch.object(shade.OpenStackCloud, 'glance_client')
+    def test_create_image_put_protected(self, glance_mock, mock_api_version):
+        mock_api_version.return_value = '2'
+        self.cloud.image_api_use_tasks = False
+
+        glance_mock.images.list.return_value = []
+        self.assertEqual([], self.cloud.list_images())
+
+        fake_image = fakes.FakeImage('42', '42 name', 'success')
+        glance_mock.images.create.return_value = fake_image
+        glance_mock.images.list.return_value = [fake_image]
+        self._call_create_image(
+            '42 name', min_disk='0', min_ram=0, properties={'int_v': 12345},
+            protected=False)
+        args = {'name': '42 name',
+                'container_format': 'bare', 'disk_format': u'qcow2',
+                'owner_specified.shade.md5': mock.ANY,
+                'owner_specified.shade.sha256': mock.ANY,
+                'owner_specified.shade.object': 'images/42 name',
+                'protected': False,
+                'int_v': '12345',
+                'visibility': 'private',
+                'min_disk': 0, 'min_ram': 0}
+        glance_mock.images.create.assert_called_with(**args)
+        glance_mock.images.upload.assert_called_with(
+            image_data=mock.ANY, image_id=fake_image.id)
+        fake_image_dict = self._image_dict(fake_image)
+        self.assertEqual([fake_image_dict], self.cloud.list_images())
+
     @mock.patch.object(occ.cloud_config.CloudConfig, 'get_api_version')
     @mock.patch.object(shade.OpenStackCloud, 'glance_client')
     def test_create_image_put_user_prop(self, glance_mock, mock_api_version):
@@ -514,13 +550,15 @@ class TestMemoryCache(base.TestCase):
         glance_mock.images.create.return_value = fake_image
         glance_mock.images.list.return_value = [fake_image]
         self._call_create_image(
-            '42 name', min_disk='0', min_ram=0, properties={'int_v': 12345})
+            '42 name', min_disk='0', min_ram=0, properties={'int_v': 12345},
+            xenapi_use_agent=False)
         args = {'name': '42 name',
                 'container_format': 'bare', 'disk_format': u'qcow2',
                 'owner_specified.shade.md5': mock.ANY,
                 'owner_specified.shade.sha256': mock.ANY,
                 'owner_specified.shade.object': 'images/42 name',
                 'int_v': '12345',
+                'xenapi_use_agent': 'False',
                 'visibility': 'private',
                 'min_disk': 0, 'min_ram': 0}
         glance_mock.images.create.assert_called_with(**args)
